@@ -15,8 +15,8 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GEDIT_CHECK_UPDATE_PLUGIN_H__
-#define __GEDIT_CHECK_UPDATE_PLUGIN_H__
+#ifndef GEDIT_CHECK_UPDATE_PLUGIN_H
+#define GEDIT_CHECK_UPDATE_PLUGIN_H
 
 #include <glib.h>
 #include <glib-object.h>
@@ -55,5 +55,5 @@ G_MODULE_EXPORT void	peas_register_types			(PeasObjectModule *module);
 
 G_END_DECLS
 
-#endif /* __GEDIT_CHECK_UPDATE_PLUGIN_H__ */
+#endif /* GEDIT_CHECK_UPDATE_PLUGIN_H */
 /* ex:set ts=8 noet: */
